@@ -74,7 +74,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     });
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    engine.load(QUrl(QStringLiteral("qrc:///main.qml")));
+    engine.loadFromModule("org.kde.kontrast", "Main");
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
